NLSL: expdat Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
expdat Module Reference

## Variables
double precision, dimension(mxpt), save | data
double precision, dimension(mxinp, 3), save | spltmp
double precision, dimension(mxspc), save | rmsn
double precision, dimension(mxspc), save | sbi
double precision, dimension(mxspc), save | sdb
double precision, dimension(mxspc), save | srng
double precision, dimension(mxspc), save | shft
double precision, dimension(mxspc), save | sb0
double precision, dimension(mxspc), save | sphs
double precision, dimension(mxspc), save | spsi
double precision, dimension(mxspc), save | slb
double precision, dimension(mxspc), save | tmpshft
integer, dimension(mxspc), save | iform
integer, dimension(mxspc), save | ibase
integer, dimension(mxspc), save | nft
integer, dimension(mxspc), save | npts
integer, dimension(mxspc), save | ishft
integer, dimension(mxspc), save | idrv
integer, dimension(mxspc), save | ixsp
integer, dimension(mxspc), save | nrmlz
integer, save | nspc
integer, save | nwin
integer, save | ndatot
integer, save | ishglb
integer, save | inform
integer, save | bcmode
integer, save | drmode
integer, save | nspline
integer, save | shftflg
integer, save | normflg
integer, save | written
character *30, dimension(mxspc), save | dataid
character *20, dimension(mxspc), save | wndoid

## Variable Documentation

integer, save expdat::bcmode

Definition at line 45 of file expdat.f90.

double precision, dimension(mxpt), save expdat::data

Definition at line 40 of file expdat.f90.

character*30, dimension(mxspc), save expdat::dataid

Definition at line 51 of file expdat.f90.

integer, save expdat::drmode

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::ibase

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::idrv

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::iform

Definition at line 45 of file expdat.f90.

integer, save expdat::inform

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::ishft

Definition at line 45 of file expdat.f90.

integer, save expdat::ishglb

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::ixsp

Definition at line 45 of file expdat.f90.

integer, save expdat::ndatot

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::nft

Definition at line 45 of file expdat.f90.

integer, save expdat::normflg

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::npts

Definition at line 45 of file expdat.f90.

integer, dimension(mxspc), save expdat::nrmlz

Definition at line 45 of file expdat.f90.

integer, save expdat::nspc

Definition at line 45 of file expdat.f90.

integer, save expdat::nspline

Definition at line 45 of file expdat.f90.

integer, save expdat::nwin

Definition at line 45 of file expdat.f90.

double precision, dimension(mxspc), save expdat::rmsn

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::sb0

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::sbi

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::sdb

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::shft

Definition at line 40 of file expdat.f90.

integer, save expdat::shftflg

Definition at line 45 of file expdat.f90.

double precision, dimension(mxspc), save expdat::slb

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::sphs

Definition at line 40 of file expdat.f90.

double precision, dimension(mxinp,3), save expdat::spltmp

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::spsi

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::srng

Definition at line 40 of file expdat.f90.

double precision, dimension(mxspc), save expdat::tmpshft

Definition at line 40 of file expdat.f90.

character*20, dimension(mxspc), save expdat::wndoid

Definition at line 52 of file expdat.f90.

integer, save expdat::written

Definition at line 45 of file expdat.f90.